| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Bio.Motif.Search
Synopsis
- findTFBS :: Monad m => Bkgd -> PWM -> DNA a -> Double -> Bool -> ConduitT i Int m ()
- findTFBS' :: Bkgd -> PWM -> DNA a -> Double -> Bool -> [Int]
- findTFBSSlow :: Monad m => Bkgd -> PWM -> DNA a -> Double -> ConduitT i Int m ()
- maxMatchSc :: Bkgd -> PWM -> DNA a -> Double
- data SpaceDistribution = SpaceDistribution {}
- spaceConstraint :: [(Motif, Motif)] -> Bkgd -> Double -> Int -> Int -> DNA a -> [SpaceDistribution]
- spaceConstraintHelper :: (Vector Int, Vector Int) -> (Vector Int, Vector Int) -> Int -> Int -> ([(Int, Int)], [(Int, Int)])
Documentation
Arguments
| :: Monad m | |
| => Bkgd | |
| -> PWM | |
| -> DNA a | |
| -> Double | |
| -> Bool | whether to skip ambiguous sequences. Recommend: True in most cases |
| -> ConduitT i Int m () |
given a user defined threshold, look for TF binding sites on a DNA sequence, using look ahead search. This function doesn't search for binding sites on the reverse strand
findTFBSSlow :: Monad m => Bkgd -> PWM -> DNA a -> Double -> ConduitT i Int m () Source #
use naive search
maxMatchSc :: Bkgd -> PWM -> DNA a -> Double Source #
the largest possible match scores starting from every position of a DNA sequence
data SpaceDistribution Source #
Constructors
| SpaceDistribution | |
Instances
| Read SpaceDistribution Source # | |
Defined in Bio.Motif.Search Methods readsPrec :: Int -> ReadS SpaceDistribution # readList :: ReadS [SpaceDistribution] # | |
| Show SpaceDistribution Source # | |
Defined in Bio.Motif.Search Methods showsPrec :: Int -> SpaceDistribution -> ShowS # show :: SpaceDistribution -> String # showList :: [SpaceDistribution] -> ShowS # | |